diff tests/test-symlink-os-yes-fs-no.py @ 37431:5ac84b20f184

tests: use unbundle in test-symlink-os-yes-fs-no.py The test (which should probably be rewritten as a .t test - the test was initially authored in 2009 and this may have predated some test harness features allowing us to implement it as a .t test) is verifying symlink behavior with regards to working directory operations. How it pulls bundle data into a repo is not relevant. So we can switch from pull to unbundle so we can support environments where bundlerepos don't work. Differential Revision: https://phab.mercurial-scm.org/D3111
author Gregory Szorc <gregory.szorc@gmail.com>
date Wed, 04 Apr 2018 17:02:54 -0700
parents d83ca854fa21
children 630429dcc397
line wrap: on
line diff
--- a/tests/test-symlink-os-yes-fs-no.py	Wed Apr 04 16:49:22 2018 -0700
+++ b/tests/test-symlink-os-yes-fs-no.py	Wed Apr 04 17:02:54 2018 -0700
@@ -21,10 +21,11 @@
 # hide outer repo
 hg.peer(u, {}, '.', create=True)
 
-# clone with symlink support
-hg.clone(u, {}, BUNDLEPATH, 'test0')
+# unbundle with symlink support
+hg.peer(u, {}, 'test0', create=True)
 
 repo = hg.repository(u, 'test0')
+commands.unbundle(u, repo, BUNDLEPATH, update=True)
 
 # wait a bit, or the status call wont update the dirstate
 time.sleep(1)
@@ -52,6 +53,8 @@
 repo = hg.repository(u, 'test0')
 commands.status(u, repo)
 
-# try cloning a repo which contains symlinks
+# try unbundling a repo which contains symlinks
 u = uimod.ui.load()
-hg.clone(u, {}, BUNDLEPATH, 'test1')
+
+repo = hg.repository(u, 'test1', create=True)
+commands.unbundle(u, repo, BUNDLEPATH, update=True)